tags = {
        '2011_MagDown_MC_Bd2Ksee': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Bd2Ksee': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Bd2Ksee': {'conddb': "sim-20130522-1-vc-md100",
                                    'dddb': "dddb-20130929-1", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2012_MagUp_MC_Bd2Ksee': {'conddb': "sim-20130522-1-vc-mu100",
                                    'dddb': "dddb-20130929-1", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2015_MagUp_MC_Bd2Ksee': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Bd2Ksee': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Bd2Ksee': {'conddb':"sim-20161124-2-vc-md100",
                                    'dddb': "dddb-20150724", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Bd2Ksee': {'conddb':"sim-20161124-2-vc-mu100",
                                    'dddb': "dddb-20150724", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Bd2Ksee': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Bd2Ksee': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Bd2Ksee': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Bd2Ksee': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11124101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Bd2KsJpsee': {'conddb':"sim-20130522-vc-md100",
                                    'dddb': "dddb-20130929", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2011_MagUp_MC_Bd2KsJpsee': {'conddb':"sim-20130522-vc-mu100",
                                    'dddb': "dddb-20130929", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2012_MagDown_MC_Bd2KsJpsee': {'conddb':"sim-20130522-1-vc-md100",
                                    'dddb': "dddb-20130929-1", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2012_MagUp_MC_Bd2KsJpsee': {'conddb':"sim-20130522-1-vc-mu100",
                                    'dddb': "dddb-20130929-1", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2015_MagUp_MC_Bd2KsJpsee': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Bd2KsJpsee': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Bd2KsJpsee': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Bd2KsJpsee': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Bd2KsJpsee': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Bd2KsJpsee': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Bd2KsJpsee': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Bd2KsJpsee': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11154100',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Bd2KsJpsmm': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20160318-1", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Bd2KsJpsmm': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20160318-1", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Bd2KsJpsmm': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20150928", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Bd2KsJpsmm': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20150928", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Bd2KsJpsmm': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20150724", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Bd2KsJpsmm': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20150724", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Bd2KsJpsmm': {'conddb':"sim-20161124-2-vc-md100",
                                    'dddb': "dddb-20150724", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Bd2KsJpsmm': {'conddb':"sim-20161124-2-vc-mu100",
                                    'dddb': "dddb-20150724", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Bd2KsJpsmm': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Bd2KsJpsmm': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Bd2KsJpsmm': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Bd2KsJpsmm': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3", 'id' : '11144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Bd2Ksmm': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1", 'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Bd2Ksmm': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Bd2Ksmm': {'conddb':"Sim08-20130503-1-vc-mu100",
                                    'dddb': "Sim08-20130503-1",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2012_MagDown_MC_Bd2Ksmm': {'conddb':"Sim08-20130503-1-vc-mu100",
                                    'dddb': "Sim08-20130503-1",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2015_MagUp_MC_Bd2Ksmm': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Bd2Ksmm': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Bd2Ksmm': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Bd2Ksmm': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Bd2Ksmm': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Bd2Ksmm': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Bd2Ksmm': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Bd2Ksmm': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11114101',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Bd2KsPsimm': {'conddb':"sim-20130522-vc-md100",
                                    'dddb': "dddb-20130929",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2011_MagUp_MC_Bd2KsPsimm': {'conddb':"sim-20130522-vc-mu100",
                                    'dddb': "dddb-20130929",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2012_MagDown_MC_Bd2KsPsimm': {'conddb':"sim-20130522-1-vc-md100",
                                    'dddb': "dddb-20130929",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2012_MagUp_MC_Bd2KsPsimm': {'conddb':"sim-20130522-vc-mu100",
                                    'dddb': "dddb-20130929",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2015_MagDown_MC_Bd2KsPsimm': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20150724",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Bd2KsPsimm': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20150724",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Bd2KsPsimm': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Bd2KsPsimm': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Bd2KsPsimm': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Bd2KsPsimm': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Bd2KsPsimm': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Bd2KsPsimm': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11144110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Bd2KsPsiee': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Bd2KsPsiee': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Bd2KsPsiee': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Bd2KsPsiee': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Bd2KsPsiee': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Bd2KsPsiee': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Bd2KsPsiee': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Bd2KsPsiee': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Bd2KsPsiee': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Bd2KsPsiee': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Bd2KsPsiee': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Bd2KsPsiee': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '11154110',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},

        '2011_MagDown_MC_Lb2Lee': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Lb2Lee': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Lb2Lee': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Lb2Lee': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Lb2Lee': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Lb2Lee': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Lb2Lee': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Lb2Lee': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Lb2Lee': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Lb2Lee': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Lb2Lee': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Lb2Lee': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15124102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Lb2Lem': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Lb2Lem': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Lb2Lem': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Lb2Lem': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Lb2Lem': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Lb2Lem': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Lb2Lem': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Lb2Lem': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Lb2Lem': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Lb2Lem': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Lb2Lem': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Lb2Lem': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15114113',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Lb2Lmm': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Lb2Lmm': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Lb2Lmm': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Lb2Lmm': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Lb2Lmm': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Lb2Lmm': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Lb2Lmm': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Lb2Lmm': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Lb2Lmm': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Lb2Lmm': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Lb2Lmm': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Lb2Lmm': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15114102',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Lb2LJpsmm': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2011_MagUp_MC_Lb2LJpsmm': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2012_MagDown_MC_Lb2LJpsmm': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2012_MagUp_MC_Lb2LJpsmm': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim08'},
        '2015_MagDown_MC_Lb2LJpsmm': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Lb2LJpsmm': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Lb2LJpsmm': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Lb2LJpsmm': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Lb2LJpsmm': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Lb2LJpsmm': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Lb2LJpsmm': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Lb2LJpsmm': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15144103',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Lb2LJpsee': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Lb2LJpsee': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Lb2LJpsee': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Lb2LJpsee': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Lb2LJpsee': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Lb2LJpsee': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Lb2LJpsee': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Lb2LJpsee': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Lb2LJpsee': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Lb2LJpsee': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Lb2LJpsee': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Lb2LJpsee': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15154105',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Lb2LPsiee': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Lb2LPsiee': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Lb2LPsiee': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Lb2LPsiee': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Lb2LPsiee': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Lb2LPsiee': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Lb2LPsiee': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Lb2LPsiee': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Lb2LPsiee': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Lb2LPsiee': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Lb2LPsiee': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Lb2LPsiee': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15154115',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Lb2LPsimm': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Lb2LPsimm': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Lb2LPsimm': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Lb2LPsimm': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Lb2LPsimm': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Lb2LPsimm': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Lb2LPsimm': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Lb2LPsimm': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Lb2LPsimm': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Lb2LPsimm': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Lb2LPsimm': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Lb2LPsimm': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15144111',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Bu2JpsiK_mm': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Bu2JpsiK_mm': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Bu2JpsiK_mm': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Bu2JpsiK_mm': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Bu2JpsiK_mm': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Bu2JpsiK_mm': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Bu2JpsiK_mm': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Bu2JpsiK_mm': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Bu2JpsiK_mm': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Bu2JpsiK_mm': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Bu2JpsiK_mm': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Bu2JpsiK_mm': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '12143001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagDown_MC_Bu2JpsiK_ee': {'conddb':"sim-20160614-1-vc-md100",
                                    'dddb': "dddb-20170721-1",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2011_MagUp_MC_Bu2JpsiK_ee': {'conddb':"sim-20160614-1-vc-mu100",
                                    'dddb': "dddb-20170721-1",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagDown_MC_Bu2JpsiK_ee': {'conddb':"sim-20160321-2-vc-md100",
                                    'dddb': "dddb-20170721-2",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2012_MagUp_MC_Bu2JpsiK_ee': {'conddb':"sim-20160321-2-vc-mu100",
                                    'dddb': "dddb-20170721-2",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagDown_MC_Bu2JpsiK_ee': {'conddb':"sim-20161124-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2015_MagUp_MC_Bu2JpsiK_ee': {'conddb':"sim-20161124-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Bu2JpsiK_ee': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagUp_MC_Bu2JpsiK_ee': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagDown_MC_Bu2JpsiK_ee': {'conddb':"sim-20190430-1-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2017_MagUp_MC_Bu2JpsiK_ee': {'conddb':"sim-20190430-1-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagDown_MC_Bu2JpsiK_ee': {'conddb':"sim-20190430-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2018_MagUp_MC_Bu2JpsiK_ee': {'conddb':"sim-20190430-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '12153001',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09'},
        '2016_MagDown_MC_Lb2Lcenu': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15574121',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09c'},
        '2016_MagUp_MC_Lb2Lcenu': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15574121',
                                    'StrippingLine': "Bu2LLK_eeLine2",
                                    'StrippingStream': "AllStreams", 'sim':'Sim09c'},
        '2016_MagDown_MC_Lb2Lcmnu': {'conddb':"sim-20170721-2-vc-md100",
                                    'dddb': "dddb-20170721-3",'id' : '15574142',
                                    'StrippingLine': "Bu2LLKNoPID_eeLine2",
                                    'StrippingStream': "Bu2LLK_NoPID.Strip", 'sim':'Sim09d'},
        '2016_MagUp_MC_Lb2Lcmnu': {'conddb':"sim-20170721-2-vc-mu100",
                                    'dddb': "dddb-20170721-3",'id' : '15574142',
                                    'StrippingLine': "Bu2LLKNoPID_eeLine2",
                                    'StrippingStream': "Bu2LLK_NoPID.Strip", 'sim':'Sim09d'},

        }
